@@ -43,6 +43,9 @@ main (int argc, char *argv[])
   /* create a server instance */
   server = gst_rtsp_server_new ();
 
+  /* We just want to bind any port here, so that tests can run in parallel */
+  gst_rtsp_server_set_service (server, "0");
+
   /* attach the server to the default maincontext */
   if ((id = gst_rtsp_server_attach (server, NULL)) == 0)
     goto failed;
